Institute for Transport & Development Policy (ITDP)
***************************************************

.. include:: _api/transport_data.itdp.rst

The RTDB is published under a modified Creative Commons BY-NC-ND 3.0 license.
The “no derivatives” clause means that there is no license granted to produce any derivative works, except as noted in the RTDB documentation:

> You may not alter, transform, or build upon this work.
> For original data files published on this site under a Creative Commons license, you may use the data to produce your own charts or other data visualizations.

To abide by the license, TDCI (and you, using these :mod:`.transport_data` tools) cannot produce any derived works except the “charts or other data visualizations” mentioned.
Data files produced by these tools should therefore remain on your personal system and not be published anywhere.
